@@ -6,7 +6,7 @@ import sys
 # adding all methods to the python path
 script_dir = os.path.dirname(os.path.realpath(__file__))
 methods_dir = script_dir + '/../method'
-methods_base_dirs = ('allele-info', 'iedbtools-utilities', 'netmhc-3.4-executable', 'netmhc-4.0-executable', 'netmhccons-1.1-executable', 'netmhcpan-2.8-executable', 'netmhcpan-3.0-executable', 'netmhcstabpan-1.0-executable', 'pickpocket-1.1-executable')
+methods_base_dirs = ('allele-info', 'iedbtools-utilities', 'netmhc-3.4-executable', 'netmhc-4.0-executable', 'netmhccons-1.1-executable', 'netmhcpan-2.8-executable', 'netmhcstabpan-1.0-executable', 'pickpocket-1.1-executable', 'netmhcpan-4.0-executable', 'mhci-netmhcpan-4.0-percentile-data', 'mhci_ann_predictor_percentile_data', 'mhci_netmhcstabpan_predictor_percentile_data')
 for method_base_dir in methods_base_dirs:
     sys.path.append(methods_dir + '/' + method_base_dir)
 
@@ -101,15 +101,21 @@ class Prediction:
 
             combined_table_rows.extend(table_rows)
 
+        combined_table_rows.sort(key=lambda tup: tup[2])
         # headers for different methods
         if method == 'IEDB_recommended':
             header = ('allele','seq_num','start','end','length','peptide','method',mhc_predictor.get_score_unit(),'ann_ic50','ann_rank','smm_ic50','smm_rank','comblib_sidney2008_score','comblib_sidney2008_rank','netmhcpan_ic50','netmhcpan_rank')
+            combined_table_rows.sort(key=lambda tup: tup[7])
         elif method == 'consensus':
             header = ('allele','seq_num','start','end','length','peptide',mhc_predictor.get_score_unit(),'ann_ic50','ann_rank','smm_ic50','smm_rank','comblib_sidney2008_score','comblib_sidney2008_rank')
+            combined_table_rows.sort(key=lambda tup: tup[6])
         else:
             header = ('allele','seq_num','start','end','length','peptide',mhc_predictor.get_score_unit(),'rank')
+            combined_table_rows.sort(key=lambda tup: tup[6])
         print '\t'.join(header)
 
+        if method == 'netmhcstabpan':
+            combined_table_rows.reverse()
         for row in combined_table_rows:
             print '\t'.join(map(str, row))
         
@@ -328,11 +334,16 @@ class Prediction:
         version_info = (
             "method\tversion\n"
             "------\t-------\n"
+            "IEDB_recommended\t2.19\n"
+            "consensus\t2.18\n"
             "ann\t4.0\n"
-            "netmhcpan\t3.0\n"
+            "netmhcpan\t4.0\n"
             "pickpocket\t1.1\n"
             "netmhccons\t1.1\n"
-            "netmhcstabpan\t1.0"
+            "netmhcstabpan\t1.0\n"
+            "comblib_sidney2008\t1.0\n"
+            "smm\t1.0\n"
+            "smmpmbec\t1.0\n"
         )
         print(version_info)
 
