@@ -7,11 +7,16 @@ import bisect
 from util import * #@UnusedWildImport
 
 from netmhc_4_0_executable import predict as predict_netmhc
-from netmhcpan_3_0_executable import predict_many as predict_netmhcpan
+from netmhcpan_4_0_executable import predict_many as predict_netmhcpan
 from pickpocket_1_1_executable import predict_single as predict_pickpocket
 from netmhccons_1_1_executable import predict_sequence as predict_netmhccons
 from netmhcstabpan_1_0_executable import predict as predict_netmhcstabpan
 
+from mhci_netmhcpan_4_0_percentile_data import score_distributions as netmhcpan_4_score_distributions
+from mhci_ann_predictor_percentile_data import score_distributions as netmhc_4_score_distributions
+from mhci_netmhcstabpan_predictor_percentile_data import score_distributions as netmhcstabpan_score_distributions
+from PercentilesCalculators import MHCIPercentilesCalculator
+
 from iedbtools_utilities.sequence_io import FASTASequenceInput
 from allele_info import MHCIAlleleData
 
@@ -261,8 +266,22 @@ class ANNPredictor:
         args = ('ann', self.mhc.replace("*",""), self.length)
         ps = PercentileScore(os.path.dirname(self.path_data), 'consensus', args)
         percentile = ps.get_percentile_score(scores)
+
+        # get percentile scores
+        allele_length_pair = (self.mhc.replace("*",""), self.length)
+        percentile = self.get_percentiles_for_scores(scores, allele_length_pair)
         return zip(scores, percentile)
 
+    def get_percentiles_for_scores(self, raw_scores, allele_length_pair):
+        ''' Returns the percentile scores for the raw scores passed. 
+        '''
+        percentiles_calculator = MHCIPercentilesCalculator(netmhc_4_score_distributions)
+        allele, binding_length = allele_length_pair
+        percentiles = percentiles_calculator.get_percentile_scores(
+                        raw_scores, 'ann', allele, binding_length)
+        return percentiles
+
+
 
 class NetMHCpanPredictor:
     def __init__(self, path_method, path_data, method_used=None):
@@ -287,13 +306,25 @@ class NetMHCpanPredictor:
 
         for scores in results.values():
             if self.mhc != "User defined":
-                args = ("netmhcpan", self.mhc, int(self.length))
-                ps = PercentileScore(self.path_data, "netmhcpan", args)
-                percentile = ps.get_percentile_score(scores)
+                allele_length_pair = (allele_name_or_sequence, self.length)
+                percentile = self.get_percentiles_for_scores(scores, allele_length_pair)
                 return zip(scores, percentile)
             else:
                 return scores
-
+    def get_percentiles_for_scores(self, raw_scores, allele_length_pair):
+        ''' Returns the percentile scores for the raw scores passed. 
+        '''
+        percentiles_calculator = MHCIPercentilesCalculator(netmhcpan_4_score_distributions)
+        allele, binding_length = allele_length_pair
+        try:
+            percentiles = percentiles_calculator.get_percentile_scores(
+                            raw_scores, 'netmhcpan', allele, binding_length)
+        except ValueError:
+            if is_user_defined_allele(allele_length_pair.allele):
+                percentiles = [None for i in xrange(len(raw_scores))]
+            else:
+                raise
+        return percentiles
 
 class PickPocketPredictor:
     def __init__(self, path_method, path_data, method_used=None):
@@ -338,10 +369,20 @@ class NetMHCStabPanPredictor:
         scores = predict_netmhcstabpan(self.mhc, str(self.length), sequence)
 
         # get percentile scores
-        args = ('netmhcstabpan', self.mhc, self.length)
-        ps = PercentileScore(os.path.dirname(self.path_data), 'netmhcstabpan', args)
-        percentile = ps.get_percentile_score(scores)
+
+        allele_length_pair = (self.mhc, self.length)
+        percentile = self.get_percentiles_for_scores(scores, allele_length_pair)
         return zip(scores, percentile)
+
+
+    def get_percentiles_for_scores(self, raw_scores, allele_length_pair):
+        ''' Returns the percentile scores for the raw scores passed. 
+        '''
+        percentiles_calculator = MHCIPercentilesCalculator(netmhcstabpan_score_distributions)
+        allele, binding_length = allele_length_pair
+        percentiles = percentiles_calculator.get_percentile_scores(
+                        raw_scores, 'netmhcstabpan', allele, binding_length)
+        return percentiles
     
 
 class NetMHCconsPredictor:
